@@ -15,6 +15,7 @@
 import logging
 
 from openstackclient.identity import common as identity_common
+from osc_lib.cli import format_columns
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils as oscutils
@@ -211,6 +212,16 @@ class ShowShareNetwork(command.ShowOne):
 
         data = share_network._info
 
+        # Special mapping for columns to make the output easier to read:
+        # 'metadata' --> 'properties'
+        for ss in data['share_network_subnets']:
+            ss.update(
+                {
+                    'properties':
+                        format_columns.DictColumn(ss.pop('metadata', {})),
+                },
+            )
+
         # Add security services information
         security_services = share_client.security_services.list(
             search_opts={'share_network_id': share_network.id}, detailed=False)
@@ -295,9 +306,7 @@ class CreateShareNetwork(command.ShowOne):
                 "Availability zone can be specified only with manila API "
                 "version >= 2.51")
         elif parsed_args.availability_zone:
-            availability_zone = oscutils.find_resource(
-                share_client.availability_zones,
-                parsed_args.availability_zone).name
+            availability_zone = parsed_args.availability_zone
 
         share_network = share_client.share_networks.create(
             name=parsed_args.name,
