@@ -37,6 +37,7 @@ SHARE_NETWORK_SUBNET = 'share_network_subnet'
 SHARE_SERVER = 'share_server'
 SNAPSHOT = 'snapshot'
 SHARE_REPLICA = 'share_replica'
+TRANSFER = 'transfer'
 
 
 def not_found_wrapper(f):
@@ -142,6 +143,8 @@ class ManilaCLIClient(base.CLIClient):
             func = self.is_message_deleted
         elif res_type == SHARE_REPLICA:
             func = self.is_share_replica_deleted
+        elif res_type == TRANSFER:
+            func = self.is_share_transfer_deleted
         else:
             raise exceptions.InvalidResource(message=res_type)
 
@@ -669,6 +672,26 @@ class ManilaCLIClient(base.CLIClient):
             SHARE_NETWORK, res_id=share_network, interval=2, timeout=6,
             microversion=microversion)
 
+    def share_network_subnet_create_check(
+            self, share_network_id, neutron_net_id=None,
+            neutron_subnet_id=None, availability_zone=None, reset=False,
+            microversion=None):
+        params = self._combine_share_network_subnet_data(
+            neutron_net_id=neutron_net_id,
+            neutron_subnet_id=neutron_subnet_id,
+            availability_zone=availability_zone)
+        cmd = (
+            'share-network-subnet-create-check %(network_id)s '
+            '%(params)s' % {
+                'network_id': share_network_id,
+                'params': params})
+
+        if reset:
+            cmd += '--reset %s' % reset
+
+        return output_parser.details(
+            self.manila(cmd, microversion=microversion))
+
     # Share Network Subnets
 
     def _combine_share_network_subnet_data(self, neutron_net_id=None,
@@ -899,6 +922,55 @@ class ManilaCLIClient(base.CLIClient):
             cmd += '%s ' % share
         return self.manila(cmd, microversion=microversion)
 
+    def create_share_transfer(self, share_id, name=None,
+                              microversion=None):
+        """Create a share transfer.
+
+        :param share_id: ID of share.
+        ":param name: name of transfer.
+        """
+        cmd = 'share-transfer-create %s ' % share_id
+        if name:
+            cmd += '--name %s' % name
+        transfer_raw = self.manila(cmd, microversion=microversion)
+        transfer = output_parser.details(transfer_raw)
+        return transfer
+
+    def delete_share_transfer(self, transfer, microversion=None):
+        """Delete a share transfer.
+
+        :param transfer: ID or name of share transfer.
+        """
+        cmd = 'share-transfer-delete %s ' % transfer
+        self.manila(cmd, microversion=microversion)
+
+    def get_share_transfer(self, transfer, microversion=None):
+        """Get a share transfer.
+
+        :param transfer: ID or name of share transfer.
+        """
+        cmd = 'share-transfer-show %s ' % transfer
+        transfer_raw = self.manila(cmd, microversion=microversion)
+        transfer = output_parser.details(transfer_raw)
+        return transfer
+
+    def list_share_transfer(self, microversion=None):
+        """Get a share transfer."""
+
+        cmd = 'share-transfer-list '
+        transfer_raw = self.manila(cmd, microversion=microversion)
+        transfers = utils.listing(transfer_raw)
+        return transfers
+
+    def accept_share_transfer(self, transfer, auth_key,
+                              microversion=None):
+        """Accept a share transfer.
+
+        :param transfer: ID or name of share transfer.
+        """
+        cmd = 'share-transfer-accept %s %s' % (transfer, auth_key)
+        self.manila(cmd, microversion=microversion)
+
     def list_shares(self, all_tenants=False, is_soft_deleted=False,
                     filters=None, columns=None, is_public=False,
                     microversion=None):
@@ -983,6 +1055,26 @@ class ManilaCLIClient(base.CLIClient):
             SHARE, res_id=share, interval=5, timeout=300,
             microversion=microversion)
 
+    def is_share_transfer_deleted(self, transfer, microversion=None):
+        """Says whether transfer is deleted or not.
+
+        :param transfer: str -- Name or ID of transfer
+        """
+        try:
+            self.get_transfer(transfer, microversion=microversion)
+            return False
+        except tempest_lib_exc.NotFound:
+            return True
+
+    def wait_for_transfer_deletion(self, transfer, microversion=None):
+        """Wait for transfer deletion by its Name or ID.
+
+        :param transfer: str -- Name or ID of transfer.
+        """
+        self.wait_for_resource_deletion(
+            SHARE, res_id=transfer, interval=5, timeout=300,
+            microversion=microversion)
+
     def wait_for_share_soft_deletion(self, share_id, microversion=None):
         body = self.get_share(share_id, microversion=microversion)
         is_soft_deleted = body['is_soft_deleted']
@@ -1497,7 +1589,8 @@ class ManilaCLIClient(base.CLIClient):
 
     def create_security_service(self, type='ldap', name=None, description=None,
                                 dns_ip=None, ou=None, server=None, domain=None,
-                                user=None, password=None, microversion=None):
+                                user=None, password=None, default_ad_site=None,
+                                microversion=None):
         """Creates security service.
 
         :param type: security service type (ldap, kerberos or active_directory)
@@ -1509,6 +1602,7 @@ class ManilaCLIClient(base.CLIClient):
         :param domain: security service domain.
         :param user: user of the new security service.
         :param password: password used by user.
+        :param default_ad_site: default AD site
         """
 
         cmd = 'security-service-create %s ' % type
@@ -1520,7 +1614,8 @@ class ManilaCLIClient(base.CLIClient):
             server=server,
             domain=domain,
             user=user,
-            password=password)
+            password=password,
+            default_ad_site=default_ad_site)
 
         ss_raw = self.manila(cmd, microversion=microversion)
         security_service = output_parser.details(ss_raw)
@@ -1530,7 +1625,8 @@ class ManilaCLIClient(base.CLIClient):
     def update_security_service(self, security_service, name=None,
                                 description=None, dns_ip=None, ou=None,
                                 server=None, domain=None, user=None,
-                                password=None, microversion=None):
+                                password=None, default_ad_site=None,
+                                microversion=None):
         cmd = 'security-service-update %s ' % security_service
         cmd += self. _combine_security_service_data(
             name=name,
@@ -1540,13 +1636,15 @@ class ManilaCLIClient(base.CLIClient):
             server=server,
             domain=domain,
             user=user,
-            password=password)
+            password=password,
+            default_ad_site=default_ad_site)
         return output_parser.details(
             self.manila(cmd, microversion=microversion))
 
     def _combine_security_service_data(self, name=None, description=None,
                                        dns_ip=None, ou=None, server=None,
-                                       domain=None, user=None, password=None):
+                                       domain=None, user=None, password=None,
+                                       default_ad_site=None):
         data = ''
         if name is not None:
             data += '--name %s ' % name
@@ -1564,6 +1662,8 @@ class ManilaCLIClient(base.CLIClient):
             data += '--user %s ' % user
         if password is not None:
             data += '--password %s ' % password
+        if default_ad_site is not None:
+            data += '--default-ad-site %s ' % default_ad_site
         return data
 
     @not_found_wrapper
@@ -1907,12 +2007,18 @@ class ManilaCLIClient(base.CLIClient):
 
     # Share replicas
 
-    def create_share_replica(self, share, microversion=None):
+    def create_share_replica(self, share, availability_zone=None,
+                             share_network=None, microversion=None):
         """Create a share replica.
 
         :param share: str -- Name or ID of a share to create a replica of
         """
         cmd = "share-replica-create %s" % share
+        if availability_zone is not None:
+            cmd += " --availability_zone " + availability_zone
+        if share_network is not None:
+            cmd += " --share_network " + share_network
+
         replica = self.manila(cmd, microversion=microversion)
         return output_parser.details(replica)
 
