@@ -37,6 +37,7 @@ class FakeShareClient(object):
         self.share_type_access = mock.Mock()
         self.quotas = mock.Mock()
         self.quota_classes = mock.Mock()
+        self.share_backups = mock.Mock()
         self.share_snapshots = mock.Mock()
         self.share_group_snapshots = mock.Mock()
         self.share_snapshot_export_locations = mock.Mock()
@@ -61,6 +62,7 @@ class FakeShareClient(object):
         self.share_group_types = mock.Mock()
         self.share_group_type_access = mock.Mock()
         self.share_servers = mock.Mock()
+        self.resource_locks = mock.Mock()
 
 
 class ManilaParseException(Exception):
@@ -1521,3 +1523,119 @@ class FakeShareServer(object):
             share_servers.append(
                 FakeShareServer.create_one_server(attrs))
         return share_servers
+
+
+class FakeResourceLock(object):
+    """Fake a resource lock"""
+
+    @staticmethod
+    def create_one_lock(attrs=None, methods=None):
+        """Create a fake resource lock
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object, with id, resource and so on
+        """
+
+        attrs = attrs or {}
+        methods = methods or {}
+        now_time = datetime.datetime.now()
+        delta_time = now_time + datetime.timedelta(minutes=5)
+
+        lock = {
+            'id': str(uuid.uuid4()),
+            'resource_id': str(uuid.uuid4()),
+            'resource_type': 'share',
+            'resource_action': 'delete',
+            'created_at': now_time.isoformat(),
+            'updated_at': delta_time.isoformat(),
+            'project_id': uuid.uuid4().hex,
+            'user_id': uuid.uuid4().hex,
+            'lock_context': 'user',
+            'lock_reason': 'created by func tests',
+        }
+
+        lock.update(attrs)
+        lock = osc_fakes.FakeResource(info=copy.deepcopy(
+            lock),
+            methods=methods,
+            loaded=True)
+        return lock
+
+    @staticmethod
+    def create_locks(attrs=None, count=2):
+        """Create multiple fake locks.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param Integer count:
+            The number of share transfers to be faked
+        :return:
+            A list of FakeResource objects
+        """
+
+        resource_locks = []
+        for n in range(0, count):
+            resource_locks.append(
+                FakeResourceLock.create_one_lock(attrs))
+
+        return resource_locks
+
+
+class FakeShareBackup(object):
+    """Fake a share Backup"""
+
+    @staticmethod
+    def create_one_backup(attrs=None, methods=None):
+        """Create a fake share backup
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object, with project_id, resource and so on
+        """
+
+        attrs = attrs or {}
+        methods = methods or {}
+
+        share_backup = {
+            'id': 'backup-id-' + uuid.uuid4().hex,
+            'share_id': 'share-id-' + uuid.uuid4().hex,
+            'status': None,
+            'name': None,
+            'description': None,
+            'size': '0',
+            'created_at': datetime.datetime.now().isoformat(),
+            'updated_at': datetime.datetime.now().isoformat(),
+            'availability_zone': None,
+            'progress': None,
+            'restore_progress': None,
+            'host': None,
+            'topic': None,
+        }
+
+        share_backup.update(attrs)
+        share_backup = osc_fakes.FakeResource(info=copy.deepcopy(
+            share_backup),
+            methods=methods,
+            loaded=True)
+        return share_backup
+
+    @staticmethod
+    def create_share_backups(attrs=None, count=2):
+        """Create multiple fake backups.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param Integer count:
+            The number of share backups to be faked
+        :return:
+            A list of FakeResource objects
+        """
+
+        share_backups = []
+        for n in range(0, count):
+            share_backups.append(
+                FakeShareBackup.create_one_backup(attrs))
+        return share_backups
