@@ -12,8 +12,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
+
 import ddt
-import mock
 
 import manilaclient
 from manilaclient import api_versions
@@ -40,6 +41,7 @@ class APIVersionTestCase(utils.TestCase):
     def test_null_version(self):
         v = api_versions.APIVersion()
         self.assertTrue(v.is_null())
+        self.assertEqual(repr(v), "<APIVersion: null>")
 
     @ddt.data(
         "2",
@@ -77,6 +79,8 @@ class APIVersionTestCase(utils.TestCase):
         self.assertLess(v5, v2)
         self.assertEqual(v_null, v_null)
         self.assertRaises(TypeError, v1.__le__, "2.1")
+        self.assertRaises(TypeError, v1.__eq__, "2.1")
+        self.assertRaises(TypeError, v1.__gt__, "2.1")
 
     def test_version_matches(self):
         v1 = api_versions.APIVersion("2.0")
@@ -115,6 +119,28 @@ class APIVersionTestCase(utils.TestCase):
         self.assertRaises(ValueError,
                           api_versions.APIVersion().get_string)
 
+    @ddt.data("2.0",
+              "2.5",
+              "2.45",
+              "3.3",
+              "3.23",
+              "2.0",
+              "3.3",
+              "4.0")
+    def test_representation(self, version):
+        version_major, version_minor = version.split('.')
+        api_version = api_versions.APIVersion(version)
+        self.assertEqual(str(api_version),
+                         ("API Version Major: %s, Minor: %s" %
+                          (version_major, version_minor)))
+        self.assertEqual(repr(api_version), "<APIVersion: %s>" % version)
+
+    def test_is_latest(self):
+        v1 = api_versions.APIVersion("1.0")
+        self.assertFalse(v1.is_latest())
+        v_latest = api_versions.APIVersion(api_versions.MAX_VERSION)
+        self.assertTrue(v_latest.is_latest())
+
 
 class GetAPIVersionTestCase(utils.TestCase):
 
